@@ -8,16 +8,16 @@ use warnings;
 
 our $VERSION = '3.00';
 
-use Apache::RequestRec;
-use Apache::RequestIO;
-use Apache::RequestUtil;
-use Apache::Util qw(:all);
-use Apache::Response;
-#use Apache::File;
+use Apache2::RequestRec;
+use Apache2::RequestIO;
+use Apache2::RequestUtil;
+use Apache2::Util qw(:all);
+use Apache2::Response;
+#use Apache2::File;
 use APR::Pool;
 use APR::Table;
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 use FKong::cgi;
 use FKong::config;
@@ -116,8 +116,8 @@ sub sendfile
    } elsif($filename =~ /\.html?$/i) {
       $r->content_type("text/html");
    }
-   #$r->set_last_modified(fileModTime($filename));   # Apache::File
-   $r->mtime(fileModTime($filename));   # Apache::RequestRec
+   #$r->set_last_modified(fileModTime($filename));   # Apache2::File
+   $r->mtime(fileModTime($filename));   # Apache2::RequestRec
    $r->headers_out->set("Last-Modified",time2str("%a, %d %b %Y %H:%M:%S %Z",$r->mtime,'GMT')); # RFC 822, updated by RFC 1123
    return if $r->header_only;
    if(! $FKong::debug || $r->content_type !~ /^text/) {
@@ -196,7 +196,7 @@ sub redirect_with_trailing_slash
 {
    my $query = $r->parsed_uri->query;
    $r->headers_out->set(Location => $r->parsed_uri->path . ($query ? "/?$query" : "/"));
-   $r->status(302); #  Apache::REDIRECT
+   $r->status(302); #  Apache2::Const::REDIRECT
 }
 
 sub fileModTime { return (stat $_[0])[9] };
@@ -273,7 +273,7 @@ sub handler {
       goto DONE;
    }
    $FKong::cgi::keyword{'warning'} = "";
-   $FKong::cgi::keyword{'version'} = "3.0";
+   $FKong::cgi::keyword{'version'} = "3.1";
    $FKong::cgi::keyword{'formurl'} = FKong::cgi::Uri("");
    $FKong::cgi::keyword{'go_to_feature'} = FKong::cgi::value_quote($FKong::cgi::form{'go_to_feature'} || "");
    $FKong::cgi::keyword{'text'} = FKong::cgi::value_quote($FKong::cgi::form{'text'} || "");
@@ -400,7 +400,7 @@ DONE:
    FKong::session::Done($r);
 FATALDONE:
    $r = undef;
-   return Apache::OK;
+   return Apache2::Const::OK;
 }
 
 
