@@ -126,6 +126,20 @@ sub query_for_comment
       push(@wheres,"(INSTR(LOWER(body),".    FKong::db::SqlQuote(lc($word)).") OR".
                    " INSTR(LOWER(subject),". FKong::db::SqlQuote(lc($word))."))");
    }
+   if(my $slang = $FKong::cgi::form{'comment_author'}) {
+      my($userid, $problem) = FKong::submit::identify_user($slang,"Author's",{});
+      if($problem) {
+         $FKong::cgi::keyword{'warning'} .= "<div class=warn>$problem</div>\n";
+         # This takes them back to the search page which is great, but does not
+         # save the query.  We should solve that more generally for all zero length
+         # query results.
+         #my $page = ($FKong::cgi::keyword{'referer'} =~ /comment\/advanced\.html/) ? 'advanced.html' : 'search.html';
+         #FKong::cgi::redirect(FKong::cgi::Uri($page));
+         push(@wheres, "0");  #  Ouch!
+      } else {
+         push(@wheres, $$fktable{'tablesql'} ."_comment.create_by = $userid");
+      }
+   }
    return [ @wheres,@{FKong::table::basic_query($fktable,$suffix)} ];
 }
 
@@ -152,7 +166,8 @@ sub show_list
    my $tablesql = $$fktable{'tablesql'};
    if($FKong::cgi::form{'delete_comment'}) {  
       delete_comment($fktable);  
-   } elsif($FKong::cgi::form{'search_comments'} && $FKong::cgi::form{'search_comments'} =~ /\S/) {  # if they are searching comments
+   } elsif($FKong::cgi::form{'search_comments'} && $FKong::cgi::form{'search_comments'} =~ /\S/ ||  # if they are searching comments
+           $FKong::cgi::form{'comment_author'} && $FKong::cgi::form{'comment_author'} =~ /\S/) { 
       my $wheres = query_for_comment($fktable,'query');
       show_table("$$fktable{'tablesql'}_comment.commentId,",$fktable,@$wheres);  
    } elsif($FKong::cgi::form{'search'}) {  # if they are not searching comments (only records)
