@@ -58,7 +58,7 @@ sub SendSQL {
        }
        if($FKong::debug) {  # if in debug mode
           FKong::Fatal("<pre>". FKong::cgi::htmlQuoteForPre("called from $filename line $line\n".
-              $db->errstr ."\n".
+              $db->errstr ."\n\n".
               $str ."\n\n") ."</pre>",'');
        } else {  # else not in debug mode
           FKong::Fatal("<p>FeatureKong had an internal error, which means it was not your fault.\n".
@@ -134,7 +134,8 @@ sub more_pages
    if($FKong::cgi::keyword{'rowCount'} =~ /(\d+)/ && $1 == $max) {
       my $skip = $max;
       $skip = $1 + $max if ($FKong::cgi::form{'skip'} || '') =~ /(\d+)/;
-      push @html, FKong::cgi::Link("",["skip=$skip", "max_rec=$max", "search=1"]) ."Next Page</a>";
+      push @html, "<A HREF=\"". FKong::cgi::Uri("",["skip=$skip", "max_rec=$max", "search=1"]) .
+                  "&$FKong::cgi::keyword{'oldQuery'}\">Next Page</a>";
    };
    return join(" | ", @html);
 }
