@@ -16,7 +16,8 @@ sub commands {
 
 my %typeNames = ( mult_choice => "Multiple Choice", integer => "Integer", hexint => 'Hex Integer', money => 'Money',
                   oneline => "One Line", multiline => "Multiple Lines", user => "User", unix_ts => 'Date Time',
-                  bool => "Boolean", float => 'Float', constant => "Constant HTML", ip => 'IP Address');
+                  bool => "Boolean", float => 'Float', constant => "Constant HTML", ip => 'IP Address',
+                  multiuser => "Multiple Users");
 
 sub yes_no { return $_[0] ? "yes" : '<font color="#888888">no</font>' }
 
@@ -260,7 +261,7 @@ sub field_keyword_details
 }
 
 my %length_of_type = ( oneline => 60, integer => 12, hexint => 12, ip => 14, money => 12, 
-                       unix_ts => 30, user => 30, float => 12, multiline => 80 );
+                       unix_ts => 30, user => 30, float => 12, multiline => 80, multiuser => 30 );
 
 $FKong::table_func{'field/new.html'} = \&new_field;
 
@@ -293,7 +294,7 @@ sub new_field
    foreach my $key (qw/on_edit_form on_new_form adv_search batch/) {
       $FKong::cgi::keyword{$key} = 'CHECKED';
    }
-   $FKong::cgi::keyword{'list_show'} = ($type eq 'multiline') ? '' : 'CHECKED';
+   $FKong::cgi::keyword{'list_show'} = ($type eq 'multiline' || $type eq 'multiuser') ? '' : 'CHECKED';
    $FKong::cgi::keyword{'create_by'} = $FKong::cgi::keyword{'mod_by'} = $FKong::cgi::keyword{'username'};
    $FKong::cgi::keyword{'sort'} = $FKong::cgi::form{'sort'} || '1000';
    index_selects($fktable,-1);
@@ -504,7 +505,7 @@ sub fix_the_index
 }
 
 my %sql_type = ( integer => "int", hexint => 'int unsigned', ip => 'int unsigned', float => "float", oneline => "text", money => 'int',
-                 multiline => "text", bool => "bool", unix_ts => 'int unsigned', user => "mediumint unsigned" );
+                 multiline => "text", bool => "bool", unix_ts => 'int unsigned', user => "mediumint unsigned", multiuser => 'text' );
 
 # This is called after the user clicks Update on the field update form.
 # It is not called to create a field.
@@ -580,7 +581,7 @@ sub Update
          $_ = FKong::db::SqlQuote($_);  
       };
       $default = FKong::db::SqlQuote($default);
-      $default = undef if ! grep { $_ eq $default } @choices;
+      $default = "NULL" if ! grep { $_ eq $default } @choices;
       FKong::db::SendSQL("ALTER TABLE $tablesql $verb COLUMN $oldSqlName $sqlName ENUM(\n  ". join(",\n  ",@choices) .") \n".
                          "DEFAULT $default");
       FKong::db::SendSQL("UPDATE field_def SET mult_choices = ". FKong::db::SqlQuote($mult_choices) ." WHERE fieldId = $fieldId");
@@ -621,9 +622,9 @@ sub create
          $_ = FKong::db::SqlQuote($_) 
       };
       $default = FKong::db::SqlQuote($default);
-      $default = undef if ! grep { $_ eq $default } @choices;
+      $default = "NULL" if ! grep { $_ eq $default } @choices;
       FKong::db::SendSQL("ALTER TABLE $tablesql ADD COLUMN $sqlName ENUM(\n  ". join(",\n  ",@choices) .") \n".
-                         "DEFAULT ". FKong::db::SqlQuote($default));
+                         "DEFAULT $default");
    }  # else must be constant 
    FKong::db::SendSQL("INSERT INTO field_def SET createTS = UNIX_TIMESTAMP(), create_by = $FKong::cgi::keyword{'userid'},\n".
                "$sql,\nsqlName = ". FKong::db::SqlQuote($sqlName) .",\nmult_choices = ". FKong::db::SqlQuote($mult_choices) );
@@ -777,11 +778,17 @@ sub drop_table_sql
    my($fktable) = @_;  
    my $tablesql = $$fktable{'tablesql'}; 
    my $sql = "<pre>\n";
-   $sql .= FKong::cgi::htmlQuoteForPre("DROP TABLE $tablesql;\n");
-   $sql .= FKong::cgi::htmlQuoteForPre("DROP TABLE ${tablesql}_change;\n") if $$fktable{'changes'};
-   $sql .= FKong::cgi::htmlQuoteForPre("DROP TABLE ${tablesql}_comment;\n") if $$fktable{'comments'};
+   $sql .= FKong::cgi::htmlQuoteForPre("DROP TABLE IF EXISTS $tablesql;\n");
+   $sql .= FKong::cgi::htmlQuoteForPre("DROP TABLE IF EXISTS ${tablesql}_change;\n") if $$fktable{'changes'};
+   $sql .= FKong::cgi::htmlQuoteForPre("DROP TABLE IF EXISTS ${tablesql}_comment;\n") if $$fktable{'comments'};
    $sql .= FKong::cgi::htmlQuoteForPre("DELETE FROM field_def WHERE tablesql = ". FKong::db::SqlQuote($tablesql) .";\n");
    $sql .= FKong::cgi::htmlQuoteForPre("DELETE FROM fktable WHERE tablesql = ". FKong::db::SqlQuote($tablesql) .";\n");
+   my $dbh = FKong::db::SendSQL("SELECT field_def.fieldId FROM field_def LEFT JOIN choice USING (fieldId)\n".
+                                "WHERE tablesql = ". FKong::db::SqlQuote($tablesql) ." AND choice IS NOT NULL\n".
+                                "GROUP BY field_def.fieldId");
+   while(my @row = $dbh->fetchrow_array) {
+      $sql .= FKong::cgi::htmlQuoteForPre("DELETE FROM choice WHERE fieldId = $row[0];\n");
+   }
    $sql .= "</pre>\n";
    return $sql;
 }
