@@ -62,13 +62,77 @@ sub print_debug
 sub TableExists ($)
 {
    my ($table) = @_;
-   my $sth = FKong::db::SendSQL("SHOW TABLES");
+   my($db,$tbl) = split(/\./,$table,2);
+   my $sth;
+   if($tbl) {
+      $sth = FKong::db::SendSQL("SHOW TABLES FROM $db LIKE ". FKong::db::SqlQuote($tbl));
+   } else {
+      $sth = FKong::db::SendSQL("SHOW TABLES LIKE ". FKong::db::SqlQuote($table));
+   }
    while ( my($dbtable) = $sth->fetchrow_array ) {
-      return 1 if ($dbtable eq $table);
+      return 1 if ($dbtable eq ($tbl || $table));
    }
    return 0;
 }
 
+sub ensure_column_exists
+{
+   my($tablesql, $fieldsql, $initial) = @_;
+
+   my $dbh = FKong::db::SendSQL("DESCRIBE $tablesql $fieldsql");
+   my($field, $dbtype, $null, $key, $default, $extra) = $dbh->fetchrow_array();
+   if(! $dbtype) {
+       FKong::db::SendSQL("ALTER TABLE $tablesql ADD COLUMN $fieldsql int unsigned");
+       FKong::db::SendSQL("UPDATE $tablesql SET $fieldsql = $initial");
+   }
+}
+
+sub auto_field_def
+{
+   my($tablesql) = @_;
+
+   my $dbh = FKong::db::SendSQL("SHOW FIELDS FROM $tablesql");
+   my $pkey = 'foo';
+   my $order = 200;
+   while(my($field,$type,$null,$key,$default,$extra) = $dbh->fetchrow_array()) {
+       my $sql;
+       $pkey = $field if $key =~ /PRI/i;
+       my @choices;  # used for multiple choice
+       if($type =~ /^enum\('(.*)'\)$/i) {
+           $sql = "type = 'mult_choice',\n";
+           @choices = split(/','/,$1);
+       } elsif($type =~ /^tinyint\(1\)/i || $type =~ /^bool/i || $type =~ /^bit/i) {
+           $sql = "type = 'bool',\n";
+       } elsif($type =~ /^float/i || $type =~ /^double/i || $type =~ /^real/i || $type =~ /^dec/i) {
+           $sql = "type = 'float',\n";
+       } elsif($type =~ /^int/i) {
+           $sql = "type = 'integer',\n";
+       } else {
+           $sql = "type = 'oneline',\n";
+       }
+       my $fixed_sql = ($field =~ /^_/) ? "0" : "1";
+       (my $fieldName = $field) =~ s/^_(.)/$1/;  # delete leading underscore if present
+       my $dbh2 = FKong::db::SendSQL("INSERT INTO field_def SET\n".
+                                     "tablesql = ". FKong::db::SqlQuote($tablesql) .",\n".
+                                     "sqlName = ". FKong::db::SqlQuote($field) .",\n".
+                                     "fieldName = ". FKong::db::SqlQuote($fieldName) .",\n".
+                                     $sql .
+                                     "sort = $order,\n".
+                                     "fixed_sql = 0,\n".
+                                     "list_show = 1\n");
+       my $fieldId = FKong::db::last_insert_id();
+       foreach my $choice (@choices) {
+          FKong::db::SendSQL("INSERT INTO choice SET fieldId = $fieldId, choice = ". FKong::db::SqlQuote($choice));
+       };
+       $order += 10;
+   }
+   ensure_column_exists($tablesql, "createTS", "UNIX_TIMESTAMP()");
+   ensure_column_exists($tablesql, "modifyTS", "UNIX_TIMESTAMP()");
+   ensure_column_exists($tablesql, "create_by", $FKong::cgi::keyword{'userid'});
+   ensure_column_exists($tablesql, "mod_by", $FKong::cgi::keyword{'userid'});
+   return $pkey;
+}
+
 $FKong::url_func{'fktable/new.html'} = \&show_create_table;
 
 sub show_create_table
@@ -97,7 +161,7 @@ sub show_create_table
         FKong::cgi::print_expanded_template("template/create-table.html"); 
         return;
      }
-     if($tablesql !~ /^\w+$/) {
+     if($tablesql !~ /^[\w\.]+$/) {
         $FKong::cgi::keyword{'warning'} .= "<div class=error>Illegal character in Table SQL</div>\n";
         FKong::cgi::print_expanded_template("template/create-table.html"); 
         return;
@@ -113,14 +177,15 @@ sub show_create_table
         FKong::cgi::print_expanded_template("template/create-table.html"); 
         return;
      }
-     if(TableExists($tablesql)) {
-        $FKong::cgi::keyword{'warning'} .= "<div class=error>Table $tablesql already exists.</div>\n";
-        FKong::cgi::print_expanded_template("template/create-table.html"); 
-        return;
-     };
      my $userid = $FKong::cgi::keyword{'userid'};
      my $changeid = $changes ? "changeId int(10) unsigned NOT NULL default '0',\n" : '';
-     FKong::db::SendSQL("CREATE TABLE `$tablesql` (\n".
+     my $page = 'type';
+     if(TableExists($tablesql)) {
+        $FKong::cgi::keyword{'warning'} .= "<div class=warn>Table $tablesql already exists. Field definitions imported.</div>\n";
+        $pkey = auto_field_def($tablesql);
+        $page = 'list';
+     } else {
+         FKong::db::SendSQL("CREATE TABLE `$tablesql` (\n".
                         "$pkey int(10) unsigned NOT NULL auto_increment primary key,\n".
                         "create_by int(10) unsigned default NULL,\n".
                         "createTS int(10) unsigned default NULL,\n".
@@ -129,7 +194,12 @@ sub show_create_table
                         $changeid .
                         "KEY `modifyTS` (`modifyTS`)\n".
                         ")");
-     FKong::db::SendSQL("CREATE TABLE `${tablesql}_change` (\n".
+        $FKong::cgi::keyword{'warning'} .= "<div class=warn>Table $tablesql created.  Please create a field...</div>\n";
+     };
+     if(TableExists($tablesql ."_changes")) {
+        $FKong::cgi::keyword{'warning'} .= "<div class=error>Table ${tablesql}_changes already exists.</div>\n";
+     } else {
+         FKong::db::SendSQL("CREATE TABLE `${tablesql}_change` (\n".
                         "changeId int(10) unsigned NOT NULL auto_increment primary key,\n".
                         "$pkey int unsigned not null,\n".
                         "create_by int(10) unsigned default NULL,\n".
@@ -140,8 +210,12 @@ sub show_create_table
                         "index($pkey,changeId),\n".
                         "index(create_by,createTS),\n".
                         "index(fieldId,createTS)\n".
-                        ")") if $changes;
-     FKong::db::SendSQL("CREATE TABLE `${tablesql}_comment` (\n".
+                        ")") if $FKong::cgi::form{'changes'};
+     }
+     if(TableExists($tablesql ."_comments")) {
+        $FKong::cgi::keyword{'warning'} .= "<div class=error>Table ${tablesql}_comments already exists.</div>\n";
+     } else {
+        FKong::db::SendSQL("CREATE TABLE `${tablesql}_comment` (\n".
                         "commentId int(10) unsigned NOT NULL auto_increment primary key,\n".
                         "$pkey int unsigned not null,\n".
                         "create_by int(10) unsigned default NULL,\n".
@@ -156,7 +230,8 @@ sub show_create_table
                         ($changeid ? "index($pkey,changeId),\n" : '') .
                         "index(create_by,createTS),\n".
                         "fulltext(subject,body)\n".
-                        ")") if $comments;
+                        ")") if $FKong::cgi::form{'comments'};
+     }
      FKong::db::SendSQL("INSERT INTO field_def (fieldName, tablesql, sqlName, type, sort) VALUES\n". 
                         "('Creator',          '$tablesql', 'create_by', 'user',    10040),\n".
                         "('Create Time',      '$tablesql', 'createTS',  'unix_ts', 10042),\n".
@@ -173,16 +248,15 @@ sub show_create_table
                         "recprefix = ". FKong::db::SqlQuote($recprefix) .",\n".
                         "url =       ". FKong::db::SqlQuote($url) .",\n".
                         "pkey =      ". FKong::db::SqlQuote($pkey) .",\n".
-                        "changes =   ". FKong::db::SqlQuote(! ! $changes) .",\n".
-                        "comments =  ". FKong::db::SqlQuote(! ! $comments) .",\n".
-                        "advertise = ". FKong::db::SqlQuote(! ! $advertise) .",\n".
+                        "changes =   ". FKong::db::SqlQuote(! ! $FKong::cgi::form{'changes'}) .",\n".
+                        "comments =  ". FKong::db::SqlQuote(! ! $FKong::cgi::form{'comments'}) .",\n".
+                        "advertise = ". FKong::db::SqlQuote(! ! $FKong::cgi::form{'advertise'}) .",\n".
                         "sort =      ". FKong::db::SqlQuote($sort_) .",\n".
                         #"down_maint =". FKong::db::SqlQuote("The $name table is still being designed.") .",\n".
                         "create_by = $userid, mod_by = $userid,\n".
                         "createTS = UNIX_TIMESTAMP(), modifyTS = UNIX_TIMESTAMP()");
-     $FKong::cgi::keyword{'warning'} = "<div class=warn>Table $tablesql created.  Please create a field...</div>\n";
-     FKong::cgi::redirect(FKong::cgi::Uri("/". FKong::cgi::urlQuote($url) ."/field/type.html"));
-   };
+     FKong::cgi::redirect(FKong::cgi::Uri("/". FKong::cgi::urlQuote($url) ."/field/$page.html"));
+   };  # end of create a new table
 =alternative
    my $fktable = New("tablesql = 'fktable'");
    $fktable->{'internal'} = 0;   # so they can access the new form
