@@ -1,5 +1,5 @@
 
-# Copyright 2003,2004 Frederick Dean
+# Copyright 2003-2006 Frederick Dean
 
 use strict;
 #use diagnostics;
@@ -8,6 +8,13 @@ use strict;
 #  Copyright (c) 2002,2003 Frederick Dean
 #
 
+#
+#  This object is a general purpose engine that can display 
+#  data in an HTML table.  It can sort arbitrarily, compose SQL
+#  and allow user selection of columns, once the table has been
+#  defined elsewhere, like in table.pm.
+#
+
 use Date::Format;
 
 use FKong::cgi;
@@ -49,7 +56,10 @@ sub ipAddress {
 # The args here are passed to the column callback
 sub new 
 {
-   my $self = { tablesql => $_[1], arg2 => $_[2], arg3 => $_[3] };
+   my $self = {};
+   shift @_;
+   $self->{'tablesql'} = shift @_;
+   $self->{'args'} = \@_;
    return bless $self;
 }
 
@@ -160,7 +170,7 @@ sub print_csv
       foreach my $nick (@{$self->{cols2}}) {  # for every column of the row
          my $value = shift(@row);
          if(defined $self->{'colfunc'}{$nick}) {
-            $value = &{$self->{'colfunc'}{$nick}}($value,$self->{'arg2'},$self->{'arg3'});
+            $value = &{$self->{'colfunc'}{$nick}}($value,@{$self->{'args'}});
             $value =~ s/<[^>]*>//g;  # remove HTML tags
             # unquote some HTML
             $value =~ s/\&amp;/\&/ig;
@@ -209,7 +219,7 @@ sub print_template_with_table
          if(!defined $value || length $value == 0) {
             $table .= "&nbsp;";  # work around old netscape bug of empty table elements not having background color
          } elsif(defined $self->{'colfunc'}{$nick}) {
-            $table .= &{$self->{'colfunc'}{$nick}}($value,$self->{'arg2'},$self->{'arg3'});
+            $table .= &{$self->{'colfunc'}{$nick}}($value,@{$self->{'args'}});
          } else {
             $table .= FKong::cgi::htmlQuote_nonempty($value);
          }
