@@ -76,7 +76,7 @@ sub email_form
       $dbh = FKong::db::SendSQL("SELECT fieldName, fktable.name, fktable.tablesql, fieldId\n".
                                 "FROM field_def\n".
                                 "INNER JOIN fktable ON (field_def.tablesql = fktable.tablesql)\n".
-                                "WHERE field_def.type = 'user' AND ! fktable.internal\n".
+                                "WHERE field_def.type IN ('user','multiuser') AND ! fktable.internal\n".
                                 "ORDER BY fktable.name, fieldName");
       while(my($field_name,$table_name,$tablesql,$field_id) = $dbh->fetchrow_array()) {
          $form .= "<tr><td>". FKong::cgi::htmlQuote("$table_name $field_name") ."</td>\n".
