@@ -41,13 +41,26 @@ sub do_comment_keywords
 sub translate_to_username
 {
    my($value,$cacheref) = @_;
-   return $value if ! $value;
-   return $$cacheref{$value} if $$cacheref{$value};  # check cache before database
-   my $dbh = FKong::db::SendSQL("SELECT username FROM user WHERE userid = ". FKong::db::SqlQuote($value));
-   my($name) = $dbh->fetchrow_array();
-   $name ||= $value;  # use numeric value if username not found
-   $$cacheref{$value} = $name;  # save in cache
-   return $name;
+   my(@need,@have);
+   foreach (split(/,/,$value)) {
+      if($$cacheref{$_}) {  # check cache before database
+         push(@have,$$cacheref{$_});
+      } else {
+         push(@need,$_);
+      }
+   }
+   if(scalar(@need)) {
+      foreach (0..$#need) { $need[$_] = FKong::db::SqlQuote($need[$_]) }  # escape
+      my $dbh = FKong::db::SendSQL("SELECT username, userid FROM user WHERE userid IN (". join(",",@need) .") ORDER BY username");
+      while(1) {
+         my($name, $id) = $dbh->fetchrow_array();
+         last if ! $id;
+         push(@have,$name);
+         $$cacheref{$id} = $name;  # save in cache
+      }
+   }
+   return $value if 0 == scalar(@have);  # return numerics if nothing found error
+   return join("\n",sort @have);
 }
 
 sub unixTimestamp {
@@ -57,8 +70,8 @@ sub unixTimestamp {
 sub yes_no { return $_[0] ? 'yes' : 'no'; }
 our %type_func = ( unix_ts => \&unixTimestamp, hexint => \&FKong::table::hex_format, bool => \&yes_no,
                    money => \&FKong::table::money_format, user => \&translate_to_username,
-                   ip => \&FKong::list::ipAddress );
-my %col_span = ( multiline => 3, oneline => 3, user => 3);
+                   ip => \&FKong::list::ipAddress, multiuser => \&translate_to_username );
+my %col_span = ( multiline => 3, oneline => 3, user => 3, multiuser => 3);
 
 #  $is_err_form show everything quite literally.
 sub show_fields
@@ -129,8 +142,10 @@ sub show_fields
             $form .= "<input name=\"$sqlName\"". ($width ? " size=$width" :"") ." value=\"". FKong::cgi::value_quote($value) ."\">";
          };
          $form .= "</td>\n<td>$short_help</td></tr>\n";
-      } elsif($type eq "multiline") {
-         $form .= "<tr><td class=t>$edit$fieldName</td>\n". 
+      } elsif($type eq "multiline" || $type eq 'multiuser') {
+         $value = translate_to_username($value,\%usercache) if $type eq 'multiuser';
+         $short_help = "<br>$short_help" if $short_help;  # add line break if non-empty
+         $form .= "<tr><td class=t>$edit$fieldName$short_help</td>\n". 
                   " <td colspan=3><textarea WRAP=HARD NAME=\"$sqlName\"". ($height ? " ROWS=$height" :'') .
                   ($width ? " COLS=$width" :'') .">". 
                   FKong::cgi::htmlQuoteForPre($value) ."</textarea></td></tr>\n";
