@@ -58,7 +58,7 @@ sub show_form
                   " <td><input name=\"$sqlName\" type=radio value=1 ". ($value?"CHECKED":"") ."> Yes \n".
                   "<input name=\"$sqlName\" type=radio value=0 ". ($value eq "0"?"CHECKED":"") ."> No \n".
                   "<input name=\"$sqlName\" type=radio value=\"\" ". ($value eq ""?"CHECKED":"") ."> Don't care</td></tr>\n";
-      } elsif($type eq "oneline" || $type eq "multiline") {  ##### if text entry
+      } elsif($type eq "oneline" || $type eq "multiline" || $type eq "user") {  ##### if text entry
          $form .= "<tr><td class=t>$edit$fieldName</td>\n". 
                   " <td colspan=3><input name=\"$sqlName\" size=60 value=\"". FKong::cgi::value_quote($value) ."\"></td></tr>\n";
       } elsif($type eq 'constant') {                     ##### if constant
@@ -66,19 +66,33 @@ sub show_form
       };
    };
    $FKong::cgi::keyword{'search_comments'} = FKong::cgi::value_quote($FKong::cgi::form{'search_comments'});
+   $FKong::cgi::keyword{'comment_author'} = FKong::cgi::value_quote($FKong::cgi::form{'comment_author'});
    $FKong::cgi::keyword{'fform'} = $form;
-   $FKong::cgi::keyword{'oldQuery'} ||= (FKong::session::get_state("$$fktable{'tablesql'}-count-query") || "");  # if not already set
+   $FKong::cgi::keyword{'oldQuery'} ||= (FKong::session::get_state("$$fktable{'tablesql'}-query") || "");  # if not already set
    FKong::cgi::print_expanded_template($template);
 }
 
 $FKong::table_func{'search.html'} = sub { 
    $FKong::cgi::keyword{'formurl'} = FKong::cgi::Uri("list.html");
-   show_form("template/search-template.html",@_[0],"basic_search"); 
+   my $sophistication = $FKong::cgi::form{'adv'} ? 'adv_search' : 'basic_search';
+   show_form("template/search-template.html",@_[0], $sophistication); 
 };
 
-$FKong::table_func{'comment/search.html'} = sub { 
+sub comment_search_form
+{
+   my($fktable, $force_adv) = @_;
    $FKong::cgi::keyword{'formurl'} = FKong::cgi::Uri("list.html");
-   show_form("template/csearch-template.html",@_[0],"basic_search"); 
+   if(! $$fktable{'comments'}) {
+      $FKong::cgi::keyword{'warning'} .= "<div class=warn>Sorry, but this table does not track comments.</div>";
+      FKong::cgi::redirect("../search.html");
+   }
+   my $sophistication = $force_adv || $FKong::cgi::form{'adv'} ? 'adv_search' : 'basic_search';
+   show_form("template/csearch-template.html",@_[0],$sophistication); 
+}
+
+$FKong::table_func{'comment/search.html'} = sub { 
+   my($fktable) = @_;
+   comment_search_form($fktable, 0);
 };
 
 $FKong::table_func{'advanced.html'} = sub { 
@@ -87,8 +101,8 @@ $FKong::table_func{'advanced.html'} = sub {
 };
 
 $FKong::table_func{'comment/advanced.html'} = sub { 
-   $FKong::cgi::keyword{'formurl'} = FKong::cgi::Uri("list.html");
-   show_form("template/adv-csearch-template.html",@_[0],"adv_search"); 
+   my($fktable) = @_;
+   comment_search_form($fktable, 1);
 };
 
 our %decoration = ( mult_choice => "", integer => "*", hexint => '*', ip => '*', money => '*',
@@ -119,7 +133,7 @@ sub show_count_form
    $FKong::cgi::keyword{'hform'} = $hform ."<select>";
    $FKong::cgi::keyword{'hrange'} = FKong::cgi::htmlQuoteForPre($FKong::cgi::form{'hrange'} || '');
    $FKong::cgi::keyword{'vrange'} = FKong::cgi::htmlQuoteForPre($FKong::cgi::form{'vrange'} || '');
-   $FKong::cgi::keyword{'oldQuery'} = (FKong::session::get_state("$$fktable{'tablesql'}-count-query") || "");
+   $FKong::cgi::keyword{'oldQuery'} = FKong::session::get_state("$$fktable{'tablesql'}-count-query");
    FKong::search::show_form("template/count_form.html",$fktable,"basic_search"); 
 }
 
