@@ -39,6 +39,10 @@ sub check_list_and_redirect
 sub identify_user
 {
    my($slang,$fieldName,$cacheref) = @_;
+   $slang =~ s/\s+$//; # remove trailing white space
+   $slang =~ s/^\s+//; # remove leading white space
+   $slang =~ s/\s+/ /; # condense duplicate white space
+   return $1 if $slang =~ /^(\d+)$/;  # if all numeric
    return undef if ! defined $slang || $slang eq '';
    return $$cacheref{$slang} if exists $$cacheref{$slang}; # if we found the userid translation in the cache
    my $dbh = FKong::db::SendSQL("SELECT userid FROM user WHERE username = ". FKong::db::SqlQuote($slang) ."\n".
@@ -151,6 +155,15 @@ sub FatallyValidateSql
             $problems .= "$fieldName is required.<br>\n" if $min && length $newValue == 0;
             ($newValue,my $problem) = identify_user($newValue,$fieldName,\%usercache);  # translate username to userid
             $problems .= $problem if $problem;
+         } elsif($type eq 'multiuser') { 
+            my @newValues;
+            foreach my $uname (split(/^/m,$newValue)) {
+               next unless $uname;
+               ($newValue,my $problem) = identify_user($uname,$fieldName,\%usercache);  # translate username to userid
+               $problems .= $problem if $problem;
+               push(@newValues,$newValue) if $newValue;
+            }
+            $newValue = join(",",sort @newValues);
          } elsif(exists $to_db_type_func{$type} && $newValue eq '' && $type ne 'bool') { 
             $newValue = undef;
          } elsif(exists $to_db_type_func{$type}) { 
@@ -191,6 +204,8 @@ sub FatallyValidateSql
    }
    if($problems) {
       FKong::db::SendSQL("UNLOCK TABLE");
+      # We need to do a redirect to stop the re-submit warnings.
+      # We save the state on the serverside.
       FKong::session::set_state("$tablesql-$recId-fail",pack("N N (n/a*)*",
                          $FKong::cgi::form{'modifyTS'},$FKong::cgi::form{'changeId'},$problems,@formstuff));
       FKong::cgi::redirect($recId ? "$$fktable{'recprefix'}$recId.html" : 'new.html');  # to avoid POST warnings
@@ -205,7 +220,8 @@ sub send_email_notifications
    return if ! $FKong::config{'SendUpdateEmails'};
    my $tablesql = $$fktable{'tablesql'};
    # determine all the user-type fields
-   my $dbh = FKong::db::SendSQL("SELECT sqlName, fieldId FROM field_def WHERE type = 'user' AND tablesql = ". FKong::db::SqlQuote($tablesql));
+   my $dbh = FKong::db::SendSQL("SELECT sqlName, fieldId FROM field_def WHERE\n".
+              "type IN ('user','multiuser') AND tablesql = ". FKong::db::SqlQuote($tablesql));
    my(@sqlNames,@field_ids);
    while(my($sql,$fieldId) = $dbh->fetchrow_array()) {
       push(@sqlNames,$sql);
@@ -217,13 +233,15 @@ sub send_email_notifications
    # determine who are the current users 
    $dbh = FKong::db::SendSQL("SELECT ". join(",",@sqlNames) ." FROM $tablesql WHERE $$fktable{'pkey'} = $recId");
    my(@userids) = $dbh->fetchrow_array();
+   @userids = grep { defined } @userids;
    if(0 == scalar @userids) {
       return;   # record not found
    }
-   @userids = grep { defined } @userids;
+   @userids = map { split(/\D/,$_) } @userids; # for multiuser
    # determine how to contact them and if we should
    my @emails;
-   $dbh = FKong::db::SendSQL("SELECT username, realname, email, email_pref, userid  FROM user WHERE userid IN (". join(",",@userids) .")");
+   my @esc_userids = map { FKong::db::SqlQuote($_) } @userids;
+   $dbh = FKong::db::SendSQL("SELECT username, realname, email, email_pref, userid  FROM user WHERE userid IN (". join(",",@esc_userids) .")");
    # for every user who will receive email
    while(my($username,$realname,$email,$email_pref,$userid) = $dbh->fetchrow_array()) {
       next if ! $email || $email !~ /\w/;  # if email address is empty 
