@@ -1,5 +1,12 @@
 
-#  Copyright 2003,2004 Frederick Dean
+#  Copyright 2003-2006 Frederick Dean
+
+# 
+#  This loads a table definition from the field_def table
+#  and composes a list.pm object to display results to the user.
+#  This file is also responsible for forming the "where" clause
+#  of queries.
+#
 
 use strict;
 
@@ -32,7 +39,9 @@ sub user_link { return FKong::session::has_priv('view_users') ? FKong::cgi::Link
 
 # This converts a database integer or other type to a human presentable form
 our %type_func = ( unix_ts => \&FKong::list::unixTimestamp, hexint => \&hex_format, money => \&money_format, bool => \&yes_no,
-                   ip => \&FKong::list::ipAddress, user => \&user_link );
+                   ip => \&FKong::list::ipAddress, user => \&user_link,
+                   multiuser => sub { FKong::record::translate_to_username($_[0], $_[3]) },
+                 );
 
 our %custom_func = ( "fktable.url" => sub { return FKong::cgi::Link("../$_[0]/list.html") . FKong::cgi::htmlQuote($_[0]) ."</a>"; } ,
                      "fktable.tablesql" => sub { return FKong::cgi::Link("../$_[0]/show_create.html") . FKong::cgi::htmlQuote($_[0]) ."</a>"; } ,
@@ -79,7 +88,7 @@ sub define_list_object
 sub force_save_column_choice
 {
    my($fktable) = @_;
-   my $tbl = FKong::list->new($$fktable{'tablesql'},$$fktable{'recprefix'},$$fktable{'url'});
+   my $tbl = FKong::list->new($$fktable{'tablesql'},$$fktable{'recprefix'},$$fktable{'url'}, {});
    define_list_object($tbl,$fktable);
    $tbl->get_column_sql([],"-T00");
 }
@@ -92,7 +101,7 @@ sub show_table
    # check that they have permission 
    FKong::session::must_have_priv("view_features");
    FKong::session::must_have_priv("view_fields") if $$fktable{'internal'};
-   my $tbl = FKong::list->new($tablesql,$recprefix,$$fktable{'url'});
+   my $tbl = FKong::list->new($tablesql,$recprefix,$$fktable{'url'}, {});
    $tbl->keep_list() if $keep_list;  # set flag to store recId list
    define_list_object($tbl,$fktable);
    # column headings
@@ -121,7 +130,7 @@ our @search_params;  # These are the URL GET parameter names which matter to the
 sub form_query_link
 {
    my $query_url = "";
-   foreach my $param (@search_params,"search_comments") {
+   foreach my $param (@search_params,"search_comments","comment_author") {
       my $value = $FKong::cgi::form{$param};
       next unless defined $value && length $value;  # skip this param if empty
       $query_url .= "&" if $query_url;
@@ -173,8 +182,11 @@ sub basic_query
       };
    };
    # Process field_def field specifications
-   my $dbh = FKong::db::SendSQL("SELECT sqlName, type, fieldName FROM field_def WHERE (basic_search OR adv_search)");
-   while(my($sqlName,$type,$fieldName) = $dbh->fetchrow_array()) {
+   my %usercache;
+   my $dbh = FKong::db::SendSQL("SELECT sqlName, type, fieldName, adv_search && ! basic_search FROM field_def\n".
+                                "WHERE (basic_search OR adv_search) && tablesql = ". FKong::db::SqlQuote($$fktable{'tablesql'}));
+   my $has_adv;
+   while(my($sqlName,$type,$fieldName,$adv_only) = $dbh->fetchrow_array()) {
       if($type eq "oneline" || $type eq "multiline") {
          next unless $FKong::cgi::form{$sqlName};
          push(@wheres,"INSTR(LOWER($sqlName),". FKong::db::SqlQuote(lc($FKong::cgi::form{$sqlName})) .")");
@@ -189,30 +201,50 @@ sub basic_query
          push(@search_params,$sqlName);
       } elsif($type eq "integer" || $type eq 'hexint' || $type eq 'ip' || $type eq 'money' || $type eq "float" || $type eq 'unix_ts'){# if min-max
          my $func = $FKong::submit::to_db_type_func{$type};
+         my $found;
          if(defined $FKong::cgi::form{"$sqlName-min"} && length FKong::cgi::trim($FKong::cgi::form{"$sqlName-min"})) {
+            $found = 1;
             my $min = $FKong::cgi::form{"$sqlName-min"};
             my $min = defined $func ? &$func($min) : $min;
             if(defined $min) {
-               push(@wheres,"$sqlName > ". FKong::db::SqlQuote($min));
+               push(@wheres,"$sqlName >= ". FKong::db::SqlQuote($min));
                push(@search_params,"$sqlName-min");
             } else {
                $FKong::cgi::keyword{'warning'} .= "<div class=warn>". FKong::cgi::htmlQuote($fieldName) ." minimum not understood.</div>\n";
             }
          }
          if(defined $FKong::cgi::form{"$sqlName-max"} && length FKong::cgi::trim($FKong::cgi::form{"$sqlName-max"})) {
+            $found = 1;
             my $max = $FKong::cgi::form{"$sqlName-max"};
             my $max = defined $func ? &$func($max) : $max;
             if(defined $max) {
-               push(@wheres,"$sqlName < ". FKong::db::SqlQuote($max));
+               push(@wheres,"$sqlName <= ". FKong::db::SqlQuote($max));
                push(@search_params,"$sqlName-max");
             } else {
                $FKong::cgi::keyword{'warning'} .= "<div class=warn>". FKong::cgi::htmlQuote($fieldName) ." maximum not understood.</div>\n";
             }
          }
-      }  # else do nothing
+         next unless $found;
+      } elsif($type eq 'user') {
+         my $slang = $FKong::cgi::form{$sqlName};
+         next unless $slang;
+         my($userid, $problem) = FKong::submit::identify_user($slang,$fieldName,\%usercache);
+         if($problem) {
+            $FKong::cgi::keyword{'warning'} .= "<div class=warn>$problem</div>\n";
+            push(@wheres, "0");  #  Ouch!
+         } else {
+            push(@wheres, $$fktable{'tablesql'} .".$sqlName = $userid");
+         }
+         push(@search_params,$sqlName);
+      } else { # else do nothing for this type
+         next;
+      }
+      # okay if reaching here the user must have entered something for this field.
+      $has_adv ||= $adv_only;
    };
    $FKong::cgi::keyword{'oldQuery'} = form_query_link();
-   FKong::session::set_state("$$fktable{'tablesql'}-$suffix",$FKong::cgi::keyword{'oldQuery'});
+   $FKong::cgi::keyword{'oldQuery'} .= '&adv=1' if $has_adv;  # append suffix to indicate advanced
+   FKong::session::set_state("$$fktable{'tablesql'}-$suffix", $FKong::cgi::keyword{'oldQuery'});
    return \@wheres;
 }
 
@@ -299,7 +331,7 @@ sub column_choice
 {
    my($fktable) = @_;
    $FKong::cgi::keyword{'formurl'} = "list.html";
-   my $tbl = FKong::list->new($$fktable{'tablesql'},$$fktable{'recprefix'},$$fktable{'url'});
+   my $tbl = FKong::list->new($$fktable{'tablesql'},$$fktable{'recprefix'},$$fktable{'url'}, {});
    define_list_object($tbl,$fktable);
    $FKong::cgi::keyword{'table'} = FKong::list::column_choice($tbl,$$fktable{'tablesql'});
    FKong::cgi::print_expanded_template("template/column_choice-template.html");
