@@ -1,12 +1,30 @@
 #!/usr/bin/perl -w
 use strict;
 
+#
+#  Basically we work the database schema.
+#
+#  Here we test creating tables with various combinations
+#  of tracking changes or allowing comments.
+#  We then use the web forms to add a bunch of columns
+#  of many different types.  We then test the changing
+#  of column types.  We then through SQL lobotomize featurekongs
+#  knowledge of the table, then use the web form to ask 
+#  featurekong to publish it again.
+#
+
 use lib ".";
 use lib "..";
 require "../featurekong_startup.pl";
 use Date::Format;
 use FKong::db;
 use htmlform;
+use Carp;
+use Getopt::Long;
+
+
+my $keep;
+GetOptions ("keep" => \$keep ) or warn "unknown option"; 
 
 my $base_url = 'http://127.0.0.1/fkong/';
 
@@ -41,21 +59,30 @@ sub get_table_definition($)
 sub drop_table_if_exists
 {
    my($tablesql) = @_;
-   if(get_table_definition($tablesql)) {
-      FKong::db::SendSQL("DROP TABLE $tablesql");
-   };
+   FKong::db::SendSQL("DROP TABLE IF EXISTS $tablesql");
 }
 
 my $debug = 0;
 
+# The choice table is redundant and used for multiple-choice types (enum)
+sub delete_unused_choices
+{
+   my $dbh = FKong::db::SendSQL("SELECT choice.fieldId FROM choice LEFT JOIN field_def USING (fieldId)\n".
+                                "WHERE fieldName IS NULL GROUP BY fieldId");
+   while(my @row = $dbh->fetchrow_array) {
+      FKong::db::SendSQL("DELETE FROM choice WHERE fieldId = $row[0]");
+   }
+}
+
 sub create_table
 {
-   my($changes, $comments, $advertise) = @_;
+   my($changes, $comments, $advertise, $existing) = @_;
    # First manually delete the test table if present because the
    # application cannot do that
    FKong::db::SendSQL("DELETE FROM fktable WHERE tablesql = ". FKong::db::SqlQuote($tablesql));
    FKong::db::SendSQL("DELETE FROM field_def WHERE tablesql = ". FKong::db::SqlQuote($tablesql));
-   drop_table_if_exists($tablesql);
+   delete_unused_choices();
+   drop_table_if_exists($tablesql) if ! $existing;
    drop_table_if_exists("${tablesql}_change");
    drop_table_if_exists("${tablesql}_comment");
    # create the table
@@ -70,7 +97,7 @@ sub create_table
    print "### $href\n" if $debug;
    $page = `$curl_cmd '$href'`;
    $form = htmlform::new($page);
-   $form->select_form_by_submit_value('Create') or die;
+   $form->select_form_by_submit_value('Create') or confess;
    $form->set_value_by_pretext('Name',$tablename);
    $form->set_value_by_pretext('SQL',$tablesql);
    $form->set_value_by_pretext('URL',$tableurl);
@@ -85,29 +112,29 @@ sub create_table
    my $dbh = FKong::db::SendSQL("SELECT * FROM fktable WHERE tablesql = ". FKong::db::SqlQuote($tablesql));
    my $hr = $dbh->fetchrow_hashref();
    if(! $$hr{'tablesql'}) {
-      die "fktable was missing record\n";
+      confess "fktable was missing record describing this table.\nCheck error_log for SQL syntax error.\n";
    }
    if(! $changes ne ! $$hr{'changes'}) {
-      die "fktable had changes bit wrong ($changes and $$hr{'changes'})\n";
+      confess "fktable had changes bit wrong ($changes and $$hr{'changes'})\n ";
    }
    if(! $comments ne ! $$hr{'comments'}) {
-      die "fktable had comments bit wrong ($comments and $$hr{'comments'})\n";
+      confess "fktable had comments bit wrong ($comments and $$hr{'comments'})\n ";
    }
    if(! $advertise ne ! $$hr{'advertise'}) {
-      die "fktable had advertise bit wrong ($advertise and $$hr{'advertise'})\n";
+      confess "fktable had advertise bit wrong ($advertise and $$hr{'advertise'})\n ";
    }
    #if($$hr{'description'} ne 'blah blah blah') {
-   #   die "fktable had decription wrong ($$hr{'description'})\n";
+   #   confess "fktable had decription wrong ($$hr{'description'})\n";
    #}
-   get_table_definition($tablesql) or die;
+   get_table_definition($tablesql) or confess;
    if(! get_table_definition($tablesql)) {
-      die "${tablesql} table did not exist\n";
+      confess "${tablesql} table did not exist\n ";
    }
    if(! $changes ne ! get_table_definition("${tablesql}_change")) {
-      die "${tablesql}_change table existence wrong\n";
+      confess "${tablesql}_change table existence wrong\n ";
    }
    if(! $comments ne ! get_table_definition("${tablesql}_comment")) {
-      die "${tablesql}_comment table existence wrong\n";
+      confess "${tablesql}_comment table existence wrong\n ";
    }
 }      
 
@@ -161,6 +188,9 @@ sub add_column
    if($type ne 'constant') {
       $form->set_value_by_pretext('Read Only',$read_only || 0) or warn "read only not on form of $type\n";
    }
+   if($type eq 'mult_choice') {
+       $form->set_value_by_pretext('one per line',"blue\nred\norange smoothie\n");
+   }
    ($href, $formcli) = $form->submit_by_name('Create',$href);
    print "### $href\n" if $debug;
    $page = `$curl_cmd $formcli '$href'`;
@@ -174,6 +204,9 @@ sub add_column
    if($type ne 'constant') {
       my $dbh = FKong::db::SendSQL("DESCRIBE $tablesql $$hr{'sqlName'}");
       my($field, $dbtype, $null, $key, $default, $extra) = $dbh->fetchrow_array();
+      if($type eq 'mult_choice') {
+         $dbtype =~ /\('blue','red','orange smoothie'\)/ or confess "wrong choices\n ";
+      }
       if(! $dbtype) {
          warn "sql table does not have field type=$type sqlName=$$hr{'sqlName'}\n";
       } else {
@@ -209,7 +242,38 @@ sub change_col_type
 change_col_type("Blue money",300,'oneline','3.00');
 change_col_type("Blue money",'3.00','integer',300);
 
+exit if $keep;
+# Here we check asking featurekong to track a table already existing
+create_table(0,0,0,1);
+delete_unused_choices();
+# Check that the choices table caches the choices correctly.
+my $dbh = FKong::db::SendSQL("SELECT fieldId FROM field_def WHERE type = 'mult_choice' AND tablesql = ". FKong::db::SqlQuote($tablesql));
+while(my @row = $dbh->fetchrow_array()) {
+   my $dbh2 = FKong::db::SendSQL("SELECT fieldId FROM choice WHERE fieldId = $row[0] AND choice = 'red'");
+   $dbh2->fetchrow_array() or die "choices table incomplete";
+}
 
+sub check_column_def
+{
+   my($fieldsql) = @_;
+   my $dbh = FKong::db::SendSQL("DESCRIBE $tablesql $fieldsql");
+   my($field, $dbtype, $null, $key, $default, $extra) = $dbh->fetchrow_array();
+   $dbtype or confess "mandatory columns missing for existing table creation"; 
+   $dbtype =~ /int/i or confess "mandatory columns wrong type"; 
+   $dbtype =~ /unsigned/i or confess "mandatory columns wrong type"; 
+
+}
+
+# Delete the mandatory columns and make sure they reappear.
+FKong::db::SendSQL("ALTER TABLE $tablesql DROP mod_by");
+FKong::db::SendSQL("ALTER TABLE $tablesql DROP create_by");
+FKong::db::SendSQL("ALTER TABLE $tablesql DROP modifyTS");
+FKong::db::SendSQL("ALTER TABLE $tablesql DROP createTS");
+create_table(0,0,0,1);
+check_column_def("mod_by");
+check_column_def("create_by");
+check_column_def("modifyTS");
+check_column_def("createTS");
 
 
 
