@@ -196,6 +196,13 @@ foreach my $indexf (0..$numFeatures) {
       } elsif($types[$index] eq "multiline") {
          my $body = random_multiline();
          $sql .= ",$sqlNames[$index] = ". FKong::db::SqlQuote($body) ."\n";
+      } elsif($types[$index] eq "multiuser") {
+         my $population = int rand(5);
+         my %users;
+         foreach (1..$population) {
+            $users{int(rand() * $num_users + 100)} = 1;
+         }
+         $sql .= ",$sqlNames[$index] = ". FKong::db::SqlQuote(join(",",sort keys %users)) ."\n";
       };
    };
    FKong::db::SendSQL($sql);
@@ -209,7 +216,7 @@ if(1) {
    foreach my $index (0..$#sqlNames) {
       if($sqlNames[$index] !~ /^_/) { # if it does not begin with underscore
          next;  # skip it
-      } elsif($types[$index] eq "oneline" || $types[$index] eq "multiline") {
+      } elsif($types[$index] eq "oneline" || $types[$index] eq "multiline" || $types[$index] eq 'multiuser') {
          $sql .= ",$sqlNames[$index] = ''\n";
       } elsif($types[$index] eq "bool") {
          $sql .= ",$sqlNames[$index] = 0\n";
