@@ -20,7 +20,7 @@ while(my $table = $dbh->fetchrow_array()) {
 }
 foreach my $table (@tables) {
    print("drop table $table\n");
-   FKong::db::SendSQL("DROP TABLE $table");
+   FKong::db::SendSQL("DROP TABLE IF EXISTS $table");
 }
 
 FKong::db::SendSQL("DELETE FROM user WHERE userid IN (97,98,99)");
